@@ -1,9 +1,6 @@
 use crate::*;
 
-use bindings::{
-    Windows::Win32::Foundation::{E_POINTER, PWSTR},
-    Windows::Win32::System::Diagnostics::Debug::*,
-};
+use bindings::{Windows::Win32::Foundation::PWSTR, Windows::Win32::System::Diagnostics::Debug::*};
 
 /// A primitive error code value returned by most COM functions.
 #[repr(transparent)]
@@ -52,7 +49,7 @@ impl HRESULT {
             if let Some(result) = some {
                 Ok(result)
             } else {
-                Err(Error::fast_error(E_POINTER))
+                Err(Error::OK)
             }
         } else {
             Err(Error::from(self))
@@ -70,6 +67,7 @@ impl HRESULT {
         Ok(op())
     }
 
+    /// # Safety
     /// If the [`Result`] is [`Ok`] converts the `T::Abi` into `T`.
     pub unsafe fn from_abi<T: Abi>(self, abi: T::Abi) -> Result<T> {
         if self.is_ok() {
@@ -149,6 +147,7 @@ impl HRESULT {
 
 unsafe impl Abi for HRESULT {
     type Abi = Self;
+    type DefaultType = Self;
 }
 
 impl<T> std::convert::From<Result<T>> for HRESULT {
