@@ -1,5 +1,4 @@
 mod array;
-mod com;
 mod delay_load;
 mod factory_cache;
 mod guid;
@@ -12,7 +11,6 @@ mod weak;
 mod weak_ref_count;
 
 pub use array::*;
-pub use com::*;
 pub use delay_load::*;
 pub use factory_cache::*;
 pub use guid::*;
