@@ -1,19 +1,27 @@
 use crate::*;
 
-use bindings::Windows::Win32::Foundation::E_POINTER;
-
 /// Provides a generic way of referring to and converting between a Rust object
 /// and its ABI equivalent.
 ///
 /// This trait is automatically used by the generated bindings and should not be
 /// used directly.
-pub unsafe trait Abi: Sized {
+pub unsafe trait Abi: Sized + Clone {
     /// The abi representation of the implementing type.
     ///
     /// # Safety
     /// `Self` and `Abi` *must* have the same exact in-memory representation.
     type Abi;
 
+    type DefaultType: Sized + Clone + PartialEq;
+
+    /// Converts from `Self::DefaultType` to `Result<T>`.
+    fn ok(value: &Self::DefaultType) -> Result<Self> {
+        unsafe {
+            let value = value as *const _ as *const Self;
+            Ok((*value).clone())
+        }
+    }
+
     /// Casts the Rust object to its ABI type without copying the object.
     fn abi(&self) -> Self::Abi {
         // It is always safe to interpret an `Abi` type's binary representation (without moving
@@ -28,8 +36,9 @@ pub unsafe trait Abi: Sized {
         self as *mut _ as *mut _
     }
 
+    /// # Safety
     /// Casts the ABI representation to a Rust object by taking ownership of the bits.
-    // Note: This default implementation is correct for all but interfaces.
+    /// This default implementation is correct for all but interfaces.
     unsafe fn from_abi(abi: Self::Abi) -> Result<Self> {
         Ok(std::mem::transmute_copy(&abi))
     }
@@ -37,8 +46,31 @@ pub unsafe trait Abi: Sized {
     fn drop_param(_: &mut Param<Self>) {}
 }
 
+unsafe impl<T> Abi for *mut T {
+    type Abi = Self;
+    type DefaultType = Self;
+}
+
+unsafe impl<T> Abi for *const T {
+    type Abi = Self;
+    type DefaultType = Self;
+}
+
 unsafe impl<T: Interface> Abi for T {
     type Abi = RawPtr;
+    type DefaultType = Option<T>;
+
+    fn ok(value: &Self::DefaultType) -> Result<Self> {
+        unsafe {
+            // For some reason, Rust can't figure out that DefaultType is an Option here.
+            let value = value as *const _ as *const Option<Self>;
+
+            match &*value {
+                Some(value) => Ok(value.clone()),
+                None => Err(Error::OK),
+            }
+        }
+    }
 
     fn set_abi(&mut self) -> *mut Self::Abi {
         panic!("set_abi should not be used with interfaces since it implies nullable.");
@@ -48,7 +80,7 @@ unsafe impl<T: Interface> Abi for T {
         let abi: RawPtr = std::mem::transmute_copy(&abi);
 
         if abi.is_null() {
-            Err(Error::fast_error(E_POINTER))
+            Err(Error::OK)
         } else {
             Ok(std::mem::transmute_copy(&abi))
         }
@@ -57,6 +89,7 @@ unsafe impl<T: Interface> Abi for T {
 
 unsafe impl<T: Interface> Abi for Option<T> {
     type Abi = RawPtr;
+    type DefaultType = Self;
 
     fn set_abi(&mut self) -> *mut Self::Abi {
         debug_assert!(self.is_none());
