@@ -6,6 +6,7 @@ mod interface;
 mod into_param;
 mod runtime_name;
 mod runtime_type;
+mod to_impl;
 
 pub use abi::*;
 pub use compose::*;
@@ -13,3 +14,4 @@ pub use interface::*;
 pub use into_param::*;
 pub use runtime_name::*;
 pub use runtime_type::*;
+pub use to_impl::*;
